#[repr(u8)]pub enum Txbrken {
NORMAL = 0,
CONTINOUS = 1,
}Variants
NORMAL = 0
Normal operation.
CONTINOUS = 1
Continuous break. Continuous break is sent immediately when this bit is set, and remains until this bit is cleared. A break may be sent without danger of corrupting any currently transmitting character if the transmitter is first disabled (TXDIS in CTL is set) and then waiting for the transmitter to be disabled (TXDISINT in STAT = 1) before writing 1 to TXBRKEN.
Implementations